
import React, { Component } from 'react';
import { DatePicker, Form } from 'antd';
import moment from 'moment';
import 'moment/locale/zh-cn';
import {getOutputValue} from '@icode-run/utils/es/dataType'

class Item extends Component {
  onChange = (date, dateString) => {
    const {param = {}} = this.props;
    if(param.onChange && typeof param.onChange === 'function') {
      param.onChange(date ? date.format('YYYY-MM-DD HH:mm:ss') : '');
    }
  }

  getValue = () => {
    const {param} = this.props;
    const value = getOutputValue({
      outputType: 'date',
      value: param.value,
    })
    return value ? moment(value) : ''
  }

  renderContent = () => {
    const {
      label,
      param = {},
      className,
      style,
      picker,

      placeholder,
      autoFocus,
      size,
      disabled,
      minDate,
      maxDate,
      locale
    } = this.props;

    const currProps = {
      ...(label ? {} : {
        className: className || '',
        style: style || {},
        value: this.getValue(),
        onChange: this.onChange,
      }),

      ...(locale ? {
        locale,
      } : {}),
      
      placeholder: placeholder,
      autoFocus: autoFocus,
      size: size,
      disabled: disabled,
      disabledDate: (current) => {
        let isDisabled = false;
        if(minDate || minDate === 0) {
          isDisabled = current < moment().add((-Number(`${minDate}`)) - 1, 'day');
        }
        if((maxDate || maxDate === 0) && !isDisabled) {
          isDisabled = current > moment().add(Number(`${maxDate}`), 'day');
        }
        return isDisabled;
      },
    }
    if(['week', 'month', 'quarter', 'year'].indexOf(picker) >= 0) {
      currProps.picker = picker;
    }
    if('showTime' === picker) {
      currProps.showTime = true;
    }

    return <DatePicker {...currProps} />;
  }
  
  render() {
    const {
      label,
      param = {},
      className,
      style,
    } = this.props;

    const content = this.renderContent();

    return label ? <Form.Item
      className={className}
      style={style}
      {...(param.name ? {
        name: param.name,
      } : {})}
      label={label}
      initialValue={this.getValue()}
      onChange={this.onChange}
      rules={param.rules}
    >
    {content}
  </Form.Item> : content
  }
}
export default Item;


